package com.diagbot.util;

import com.diagbot.dto.BillMsg;
import com.diagbot.dto.RuleSimpleDTO;
import com.diagbot.enums.ConEnum;
import com.diagbot.enums.RedisEnum;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @description: 提示语工具类
 * @author: zhoutg
 * @time: 2020/9/14 11:16
 */
@Component
public class MsgNewUtil {

    @Autowired
    RedisUtil redisUtil;

    /**
     * 开单合理性通用提示信息
     *
     * @param ruleSimpleDTO
     * @return
     */
    public BillMsg getCommonBillMsg(RuleSimpleDTO ruleSimpleDTO) {
        String orderName = ruleSimpleDTO.getInputName(); // 医院名称
        String orderStandName = ruleSimpleDTO.getLibName(); // 标准名称
        String orderType = ruleSimpleDTO.getLibTypeName(); // 开单项类型
        String content = ruleSimpleDTO.getContent(); // 界面匹配内容
        String conType = ruleSimpleDTO.getConType(); // 禁忌类型
        String unionMsg = ruleSimpleDTO.getMsg(); // 原因及建议
        String msg = redisUtil.getByKeyAndField(RedisEnum.msg.getName(), orderType + "_" + conType);
        if (StringUtil.isBlank(msg)) {
            // msg = redisUtil.getByKeyAndField(RedisEnum.msg.getName(), "通用" + "_" + "默认提示语");
            msg = "";
        }
        BillMsg billMsg = new BillMsg();
        // 出现2个“具有”，去除一个为空
        if (ConEnum.medEqu.getName().equals(conType) && StringUtil.isNotBlank(content)
                && content.startsWith("具有") && msg.startsWith("该患者具有")) {
            msg = msg.replaceAll("具有", "");
        }
        if (StringUtil.isNotBlank(unionMsg)) {
            msg = msg.replaceAll("\\[原因及建议]", "，" + unionMsg);
        } else {
            msg = msg.replaceAll("\\[原因及建议]", "");
        }
        // [性别取反]标签替换
        if (ConEnum.gender.getName().equals(conType)) {
            if ("男".equals(content)) {
                msg = msg.replaceAll("\\[性别取反]", "女");
            } else if ("女".equals(content)) {
                msg = msg.replaceAll("\\[性别取反]", "男");
            }
        }

        // 放到最后统一替换【多处匹配】
        msg = msg.replaceAll("\\[匹配内容]", content);
        msg = msg.replaceAll("\\[开单名称]", orderName);
        billMsg.setMsg(msg);
        billMsg.setOrderName(orderName);
        billMsg.setOrderStandName(orderStandName);
        billMsg.setContent(content);
        billMsg.setType(conType);
        return billMsg;
    }
}
